@@ -57,10 +57,10 @@ class Plugin(socketio.ClientNamespace):
 
 class ExportPlugin(Plugin):
 
-    def __init__(self, id: str, secret: str, api_key: str, callback: Callable[[str, dict], Tuple[str, BytesIO]],
+    def __init__(self, id: str, secret: str, callback: Callable[[str, dict], Tuple[str, BytesIO]],
                  host="https://api.ango.ai"):
         super().__init__(id, secret, callback)
-        self.sdk = SDK(api_key=api_key, host=host)
+        self.host = host
 
     def on_plugin(self, data):
         """
@@ -72,22 +72,27 @@ class ExportPlugin(Plugin):
         updated_at = None
         project_id = data.get('projectId')
         logger = super()._get_logger(data)
+        api_key = data.get('apiKey')
+        sdk = SDK(api_key=api_key, host=self.host)
+
+
         if data.get("completed_at", None):
             completed_at = [datetime.datetime.fromisoformat(data.completed_at[0]),
                             datetime.datetime.fromisoformat(data.completed_at[1])]
         if data.get("updated_at", None):
             updated_at = [datetime.datetime.fromisoformat(data.updated_at[0]),
                           datetime.datetime.fromisoformat(data.updated_at[1])]
-        json_export = self.sdk.export(project_id, data.get('assignees', None), completed_at=completed_at,
+        json_export = sdk.export(project_id, data.get('assignees', None), completed_at=completed_at,
                                       updated_at=updated_at, batches=data.get('tags', None))
         data["jsonExport"] = json_export
         data["logger"] = logger
         file_name, export_bytes = self.callback(**data)
-        upload_url = self.sdk._get_upload_url(file_name)
+        upload_url = sdk._get_upload_url(file_name)
         upload_resp = requests.put(upload_url, data=export_bytes.getvalue())
         if upload_resp.status_code != 200:
             logging.getLogger().error("Unable to upload exports!")
         response = {
+            "export": True,
             "response": upload_url.split("?")[0],
             "session": data.get("session", "")
         }
