@@ -261,7 +261,7 @@ class SDK:
         url = "%s/v2/export?project=%s&labeledAt=true&reviewedAt=true&completion=true&duration=true&skip=true&" \
               "reviewConf=true&format=json&consensus=true&assetStatus=true&labelDuration=true&updateInfo=true&" \
               "issues=true&mask=true&segmentationPoints=true&annotationMetadata=true&benchmark=true&" \
-              "labelStatus=true&sendEmail=false&doNotNotify=true" % (self.host, project_id)
+              "labelStatus=true&sendEmail=false&doNotNotify=true&batches=true" % (self.host, project_id)
         if type(assignees) == list and len(assignees) > 0:
             url += "&assignee=" + json.dumps(assignees)
         if type(batches) == list and len(batches) > 0:
